==> iartisan-runtime-1.0.8-sources.jar: org/iartisan/runtime/web/contants/ReqContants.java <==
package org.iartisan.runtime.web.contants;

/**
 * <p>
 * requestmapping 常量类
 *
 * @author King
 * @since 2017/6/26
 */
public class ReqContants {

    public static final String REQ_AUTHENTICATE = "/authenticate";

    public static final String REQ_LOGOUT = "/logout";

    public static final String REQ_INDEX = "/index";

    public static final String REQ_MAIN = "/main";

    public static final String REQ_QUERY_PAGE_DATA = "queryPageData";

    public static final String REQ_QUERY_DATA_DIALOG = "queryDataDialog";

    public static final String REQ_QUERY_LIST_DATA = "queryListData";

    public static final String REQ_QUERY_DETAIL_DATA = "queryDetailData";

    public static final String REQ_QUERY_DETAIL_PAGE = "queryDetailPage";

    public static final String REQ_QUERY_DETAIL_DIALOG = "queryDetailDialog";

    public static final String REQ_MODIFY_DATA = "modifyData";

    public static final String REQ_MODIFY_DATA_DIALOG = "modifyDataDialog";

    public static final String REQ_MODIFY_DATA_PAGE = "modifyDataPage";

    public static final String REQ_ADD_DATA = "addData";

    public static final String REQ_ADD_DATA_DIALOG = "addDataDialog";

    public static final String REQ_ADD_DATA_PAGE = "addDataPage";

    public static final String REQ_DELETE_DATA = "deleteData";

    public static final String REQ_DELETE_DATA_DIALOG = "deleteDataDialog";

    public static final String REQ_DELETE_DATA_PAGE = "deleteDataPage";

    public static final String REQ_EXPORT_DATA_LIST = "exportListData";

    public static final String REQ_LOGIN = "/login";//登录页面

    public static final String REQ_DECORATOR = "/decorator";//装饰页面

}

==> iartisan-runtime-1.1.1-sources.jar: org/iartisan/runtime/web/contants/ReqContants.java <==
package org.iartisan.runtime.web.contants;

/**
 * <p>
 * requestmapping 常量类
 *
 * @author King
 * @since 2017/6/26
 */
public class ReqContants {

    /**
     * app前缀
     */
    public static final String REQ_PREFIX_APP = "/app";
    /**
     * h5前缀
     */
    public static final String REQ_PREFIX_H5 = "/h5";
    /**
     * 小程序前缀
     */
    public static final String REQ_PREFIX_MINIAPP = "/miniapp";

    public static final String REQ_AUTHENTICATE = "/authenticate";

    public static final String REQ_LOGOUT = "/logout";

    public static final String REQ_INDEX = "/index";

    public static final String REQ_MAIN = "/main";

    public static final String REQ_QUERY_PAGE_DATA = "queryPageData";

    public static final String REQ_QUERY_DATA_DIALOG = "queryDataDialog";

    public static final String REQ_QUERY_LIST_DATA = "queryListData";

    public static final String REQ_QUERY_DETAIL_DATA = "queryDetailData";

    public static final String REQ_QUERY_DETAIL_PAGE = "queryDetailPage";

    public static final String REQ_QUERY_DETAIL_DIALOG = "queryDetailDialog";

    public static final String REQ_MODIFY_DATA = "modifyData";

    public static final String REQ_MODIFY_DATA_DIALOG = "modifyDataDialog";

    public static final String REQ_MODIFY_DATA_PAGE = "modifyDataPage";

    public static final String REQ_ADD_DATA = "addData";

    public static final String REQ_ADD_DATA_DIALOG = "addDataDialog";

    public static final String REQ_ADD_DATA_PAGE = "addDataPage";

    public static final String REQ_DELETE_DATA = "deleteData";

    public static final String REQ_DELETE_DATA_DIALOG = "deleteDataDialog";

    public static final String REQ_DELETE_DATA_PAGE = "deleteDataPage";

    public static final String REQ_EXPORT_DATA_LIST = "exportListData";

    public static final String REQ_LOGIN = "/login";//登录页面

    public static final String REQ_DECORATOR = "/decorator";//装饰页面

}
